'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pxToRem = require('../utils/px-to-rem.js');

/**
 * Pixel size values for each font that we use in the design system.
 *
 * We assert that the values match the guardian type scale in our
 * {@link [unit test suite](./typography.test.ts)}.
 */
const pxTextSizes = {
    textSans: {
        xxsmall: 12,
        xsmall: 14,
        small: 15,
        medium: 17,
        large: 20,
        xlarge: 24,
        xxlarge: 28,
        xxxlarge: 34,
    },
    body: {
        xsmall: 14,
        small: 15,
        medium: 17,
    },
    headline: {
        xxxsmall: 17,
        xxsmall: 20,
        xsmall: 24,
        small: 28,
        medium: 34,
        large: 42,
        xlarge: 50,
    },
    titlepiece: {
        small: 42,
        medium: 50,
        large: 70,
    },
};
/**
 * Relative font sizes, calculated from the pixel sizes above;
 * using the pxToRem method.
 *
 * We assert that the computed rem values match the expected values
 * in our {@link [unit test suite](./typography.test.ts)}.
 *
 * See {@link [pxToRem](../utils/px-to-rem.ts)} for more details.
 */
const remTextSizes = {
    textSans: {
        xxsmall: pxToRem.pxToRem(pxTextSizes.textSans.xxsmall),
        xsmall: pxToRem.pxToRem(pxTextSizes.textSans.xsmall),
        small: pxToRem.pxToRem(pxTextSizes.textSans.small),
        medium: pxToRem.pxToRem(pxTextSizes.textSans.medium),
        large: pxToRem.pxToRem(pxTextSizes.textSans.large),
        xlarge: pxToRem.pxToRem(pxTextSizes.textSans.xlarge),
        xxlarge: pxToRem.pxToRem(pxTextSizes.textSans.xxlarge),
        xxxlarge: pxToRem.pxToRem(pxTextSizes.textSans.xxxlarge),
    },
    body: {
        xsmall: pxToRem.pxToRem(pxTextSizes.body.xsmall),
        small: pxToRem.pxToRem(pxTextSizes.body.small),
        medium: pxToRem.pxToRem(pxTextSizes.body.medium),
    },
    headline: {
        xxxsmall: pxToRem.pxToRem(pxTextSizes.headline.xxxsmall),
        xxsmall: pxToRem.pxToRem(pxTextSizes.headline.xxsmall),
        xsmall: pxToRem.pxToRem(pxTextSizes.headline.xsmall),
        small: pxToRem.pxToRem(pxTextSizes.headline.small),
        medium: pxToRem.pxToRem(pxTextSizes.headline.medium),
        large: pxToRem.pxToRem(pxTextSizes.headline.large),
        xlarge: pxToRem.pxToRem(pxTextSizes.headline.xlarge),
    },
    titlepiece: {
        small: pxToRem.pxToRem(pxTextSizes.titlepiece.small),
        medium: pxToRem.pxToRem(pxTextSizes.titlepiece.medium),
        large: pxToRem.pxToRem(pxTextSizes.titlepiece.large),
    },
};
const fonts = {
    titlepiece: 'GT Guardian Titlepiece, Georgia, serif',
    headline: 'GH Guardian Headline, Guardian Egyptian Web, Georgia, serif',
    body: 'GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif',
    textSans: 'GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif',
};
/**
 * @see https://theguardian.design/2a1e5182b/p/0578f1-typography-presets/b/4704a2
 * @see https://www.figma.com/file/OqhZwB5nboFn33iHLYoc6d/%E2%97%90-Typography?type=design&node-id=384%3A3&t=mYsLeX87mBF2Uw8J-1
 *
 * Relative units ensure users can change their user-agent’s font size
 * and having the line height grow accordingly.
 *
 * We meet the Web Consortium Accessibility Guidelines’
 * success criterion for “Text Spacing” (1.4.12) as these values
 * can be overridden by users.
 *
 * @see https://www.w3.org/WAI/WCAG21/Understanding/text-spacing
 */
const lineHeights = {
    tight: 1.15,
    regular: 1.3,
    loose: 1.4,
};
const fontWeights = {
    light: 300,
    regular: 400,
    medium: 500,
    bold: 700,
};
const availableFontWeights = {
    titlepiece: { bold: true },
    headline: { light: true, medium: true, bold: true },
    body: { regular: true, bold: true },
    textSans: { regular: true, bold: true },
};
const italicsFontWeights = {
    titlepiece: { bold: false },
    headline: { light: true, medium: true, bold: false },
    body: { regular: true, bold: true },
    textSans: { regular: true, bold: false },
};
const underlineThickness = {
    textSans: {
        xxsmall: 2,
        xsmall: 2,
        small: 2,
        medium: 2,
        large: 3,
        xlarge: 3,
        xxlarge: 3,
        xxxlarge: 4,
    },
    body: {
        xsmall: 2,
        small: 2,
        medium: 2,
    },
    headline: {
        xxxsmall: 2,
        xxsmall: 3,
        xsmall: 3,
        small: 3,
        medium: 4,
        large: 5,
        xlarge: 6,
    },
    titlepiece: {
        small: 5,
        medium: 6,
        large: 6,
    },
};
// Pixel font size exports
const textSansSizes = pxTextSizes.textSans;
const bodySizes = pxTextSizes.body;
const headlineSizes = pxTextSizes.headline;
const titlepieceSizes = pxTextSizes.titlepiece;
// Computed rem font size exports
const remBodySizes = remTextSizes.body;
const remTitlepieceSizes = remTextSizes.titlepiece;
const remHeadlineSizes = remTextSizes.headline;
const remTextSansSizes = remTextSizes.textSans;

exports.availableFontWeights = availableFontWeights;
exports.bodySizes = bodySizes;
exports.fontWeights = fontWeights;
exports.fonts = fonts;
exports.headlineSizes = headlineSizes;
exports.italicsFontWeights = italicsFontWeights;
exports.lineHeights = lineHeights;
exports.pxTextSizes = pxTextSizes;
exports.remBodySizes = remBodySizes;
exports.remHeadlineSizes = remHeadlineSizes;
exports.remTextSansSizes = remTextSansSizes;
exports.remTextSizes = remTextSizes;
exports.remTitlepieceSizes = remTitlepieceSizes;
exports.textSansSizes = textSansSizes;
exports.titlepieceSizes = titlepieceSizes;
exports.underlineThickness = underlineThickness;
//# sourceMappingURL=data.js.map
